@@ -83,8 +83,8 @@ class Trainer:
         policy_tag_to_agent_id_map=None,
         create_separate_placeholders_for_each_policy=False,
         obs_dim_corresponding_to_num_agents="first",
-        device_id=0,
         num_devices=1,
+        device_id=0,
         results_dir=None,
         verbose=True,
     ):
@@ -95,7 +95,7 @@ class Trainer:
             policy_tag_to_agent_id_map:
                 a dictionary mapping policy tag to agent ids.
             create_separate_placeholders_for_each_policy:
-                flag indicating whether there exist separate observations,
+                a flag indicating whether there exist separate observations,
                 actions and rewards placeholders, for each policy,
                 as designed in the step function. The placeholders will be
                 used in the step() function and during training.
@@ -113,12 +113,13 @@ class Trainer:
                 WarpDrive to process the observations correctly. This is only
                 relevant when a single obs key corresponds to multiple agents.
                 Defaults to "first".
-            device_id: device ID
-            num_devices: number of GPU devices in the train, if more than one,
-                will use the distributed training pipeline among num_devices.
+            num_devices: number of GPU devices used for (distributed) training.
+                Defaults to 1.
+            device_id: device ID. This is set in the context of multi-GPU training.
             results_dir: (optional) name of the directory to save results into.
             verbose:
-                if enabled, training metrics are printed to the screen.
+                if False, training metrics are not printed to the screen.
+                Defaults to True.
         """
         assert env_wrapper is not None
         assert env_wrapper.use_cuda
@@ -889,7 +890,8 @@ class Trainer:
 
     def graceful_close(self):
         # Delete the sample controller to clear
-        # the random seeds defined in the CUDA memory heap
+        # the random seeds defined in the CUDA memory heap.
+        # Warning: Not closing gracefully could lead to a memory leak.
         del self.cuda_sample_controller
         if self.verbose:
             verbose_print("Trainer exits gracefully", self.device_id)
@@ -927,7 +929,7 @@ class Trainer:
                 [np.ones(array_shape) for _ in range(env.episode_length + 1)]
             )
 
-        for timestep in range(env.episode_length + 1):
+        for timestep in range(env.episode_length):
             # Update the episode states
             for state in list_of_states:
                 episode_states[state][
@@ -948,7 +950,7 @@ class Trainer:
             if env.cuda_data_manager.pull_data_from_device("_done_")[env_id]:
                 for state in list_of_states:
                     episode_states[state][
-                        timestep
+                        timestep + 1
                     ] = self.cuda_envs.cuda_data_manager.pull_data_from_device(state)[
                         env_id
                     ]
